This is an automated email from the ASF dual-hosted git repository.

xiaoxiang pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/incubator-nuttx.git

commit a0ca68649030967334afff00164c3c7a0781450a
Author: Michael Jung <[email protected]>
AuthorDate: Thu Mar 18 08:16:29 2021 +0100

    stm32l5: Rename up_waste to stm32l5_waste
    
    To comply to NuttX naming conventions.
    
    Signed-off-by: Michael Jung <[email protected]>
---
 arch/arm/src/stm32l5/stm32l5_flash.c | 8 ++++----
 arch/arm/src/stm32l5/stm32l5_lse.c   | 2 +-
 arch/arm/src/stm32l5/stm32l5_waste.c | 2 +-
 arch/arm/src/stm32l5/stm32l5_waste.h | 8 ++++----
 4 files changed, 10 insertions(+), 10 deletions(-)

diff --git a/arch/arm/src/stm32l5/stm32l5_flash.c 
b/arch/arm/src/stm32l5/stm32l5_flash.c
index 5f93d97..23f5d1c 100644
--- a/arch/arm/src/stm32l5/stm32l5_flash.c
+++ b/arch/arm/src/stm32l5/stm32l5_flash.c
@@ -152,7 +152,7 @@ static void flash_unlock(void)
 {
   while (getreg32(STM32L5_FLASH_NSSR) & FLASH_SR_BSY)
     {
-      up_waste();
+      stm32l5_waste();
     }
 
   if (getreg32(STM32L5_FLASH_NSCR) & FLASH_CR_LOCK)
@@ -201,7 +201,7 @@ static inline void flash_erase(size_t page)
 
   while (getreg32(STM32L5_FLASH_NSSR) & FLASH_SR_BSY)
     {
-      up_waste();
+      stm32l5_waste();
     }
 
   modifyreg32(STM32L5_FLASH_NSCR, FLASH_CR_PAGE_ERASE, 0);
@@ -274,7 +274,7 @@ uint32_t stm32l5_flash_user_optbytes(uint32_t clrbits, 
uint32_t setbits)
 
   while (getreg32(STM32L5_FLASH_NSSR) & FLASH_SR_BSY)
     {
-      up_waste();
+      stm32l5_waste();
     }
 
   flash_optbytes_lock();
@@ -476,7 +476,7 @@ ssize_t up_progmem_write(size_t addr, const void *buf, 
size_t buflen)
 
           while (getreg32(STM32L5_FLASH_NSSR) & FLASH_SR_BSY)
             {
-              up_waste();
+              stm32l5_waste();
             }
 
           /* Verify */
diff --git a/arch/arm/src/stm32l5/stm32l5_lse.c 
b/arch/arm/src/stm32l5/stm32l5_lse.c
index 35ad78e..852fb30 100644
--- a/arch/arm/src/stm32l5/stm32l5_lse.c
+++ b/arch/arm/src/stm32l5/stm32l5_lse.c
@@ -194,7 +194,7 @@ void stm32l5_rcc_enablelse(void)
           while (!((regval = getreg32(STM32L5_RCC_BDCR)) &
                    RCC_BDCR_LSESYSRDY))
             {
-              up_waste();
+              stm32l5_waste();
             }
         }
 
diff --git a/arch/arm/src/stm32l5/stm32l5_waste.c 
b/arch/arm/src/stm32l5/stm32l5_waste.c
index f529d4f..1afc128 100644
--- a/arch/arm/src/stm32l5/stm32l5_waste.c
+++ b/arch/arm/src/stm32l5/stm32l5_waste.c
@@ -36,7 +36,7 @@ uint32_t idle_wastecounter = 0;
  * Public Functions
  *****************************************************************************/
 
-void up_waste(void)
+void stm32l5_waste(void)
 {
   idle_wastecounter++;
 }
diff --git a/arch/arm/src/stm32l5/stm32l5_waste.h 
b/arch/arm/src/stm32l5/stm32l5_waste.h
index 83b57ef..edba12a 100644
--- a/arch/arm/src/stm32l5/stm32l5_waste.h
+++ b/arch/arm/src/stm32l5/stm32l5_waste.h
@@ -44,16 +44,16 @@ extern "C"
 
 /* Waste CPU Time
  *
  * up_waste() is the logic that will be executed when portions of kernel
  * or user-app is polling some register or similar, waiting for desired
- * status. This time is wasted away. This function offers a measure of
- * badly written piece of software or some undesired behavior.
+ * status. This time is wasted away. This function offers a measure of badly
+ * written piece of software or some undesired behavior.
  *
  * At the same time this function adds to some IDLE time which portion
  * cannot be used for other purposes (yet).
  */
 
-void up_waste(void);
+void stm32l5_waste(void);
 
 #undef EXTERN
 #if defined(__cplusplus)
@@ -44,16 +44,16 @@ extern "C"
 /* Waste CPU Time
  *
- * up_waste() is the logic that will be executed when portions of kernel
+ * stm32l5_waste() is the logic that will be executed when portions of kernel
  * or user-app is polling some register or similar, waiting for desired

Reply via email to